@@ -468,9 +468,14 @@ QString Application::section()
 {
     return package()->section();
 }
+
 AbstractResource::State Application::state()
 {
+    if (!package())
+        return Broken;
+
     State ret = None;
+
     int s = package()->state();
     if(s & QApt::Package::Upgradeable) ret = Upgradeable;
     else if(s & QApt::Package::Installed) ret = Installed;
