@@ -96,8 +96,7 @@ class MUONPRIVATE_EXPORT AbstractResource : public QObject
         virtual QUrl thumbnailUrl() = 0;
         virtual QUrl screenshotUrl() = 0;
         
-        virtual int downloadSize() = 0;
-        virtual QString sizeDescription();
+        virtual QString sizeDescription() = 0;
         virtual QString license() = 0;
         
         virtual QString installedVersion() const = 0;
@@ -111,7 +110,6 @@ class MUONPRIVATE_EXPORT AbstractResource : public QObject
         virtual QString mimetypes() const;
         
         virtual QList<PackageState> addonsInformation() = 0;
-        bool isFromSecureOrigin() const;
         
         virtual QStringList executables() const;
 
@@ -123,10 +121,8 @@ class MUONPRIVATE_EXPORT AbstractResource : public QObject
         virtual QString status();
 
         AbstractResourcesBackend* backend() const;
-
     public slots:
         virtual void fetchScreenshots();
-        virtual void fetchChangelog() = 0;
 
     signals:
         void stateChanged();
@@ -134,7 +130,6 @@ class MUONPRIVATE_EXPORT AbstractResource : public QObject
         ///response to the fetchScreenshots method
         ///@p thumbnails and @p screenshots should have the same number of elements
         void screenshotsFetched(const QList<QUrl>& thumbnails, const QList<QUrl>& screenshots);
-        void changelogFetched(const QString& changelog);
 };
 
 #endif // ABSTRACTRESOURCE_H
