@@ -27,8 +27,6 @@
 
 #include "libmuonprivate_export.h"
 
-class MuonMainWindow;
-class KDialog;
 class KXmlGuiWindow;
 class KAction;
 class KActionCollection;
@@ -43,17 +41,15 @@ class MUONPRIVATE_EXPORT QAptActions : public QObject
     Q_OBJECT
 public:
     static QAptActions* self();
-    void setMainWindow(MuonMainWindow* w);
-    MuonMainWindow* mainWindow() const;
+    void setMainWindow(KXmlGuiWindow *parent);
 
     bool isConnected() const;
     void setOriginalState(QApt::CacheState state);
     void setReloadWhenEditorFinished(bool reload);
     void initError();
-    void displayTransactionError(QApt::ErrorCode error, QApt::Transaction* trans);
-    KActionCollection* actionCollection();
     
 signals:
+    void checkForUpdates();
     void shouldConnect(bool isConnected);
     void changesReverted();
     void sourcesEditorClosed(bool reload);
@@ -62,6 +58,7 @@ signals:
 public slots:
     void setBackend(QApt::Backend *backend);
     void setupActions();
+    void setActionsEnabled(bool enabled = true);
     void networkChanged();
 
     // KAction slots
@@ -76,15 +73,6 @@ public slots:
     void revertChanges();
     void runSourcesEditor();
     void sourcesEditorFinished(int exitStatus);
-    void showHistoryDialog();
-    void setActionsEnabled(bool enabled = true);
-
-private slots:
-    void closeHistoryDialog();
-    void setActionsEnabledInternal(bool enabled);
-    void checkDistUpgrade();
-    void launchDistUpgrade();
-    void checkerFinished(int res);
 
 private:
     QAptActions();
@@ -92,12 +80,11 @@ private:
     QApt::Backend *m_backend;
     QApt::CacheState m_originalState;
     bool m_actionsDisabled;
-    MuonMainWindow* m_mainWindow;
+    KXmlGuiWindow* m_mainWindow;
     bool m_reloadWhenEditorFinished;
-    
-    KDialog* m_historyDialog;
     QList<KAction *> m_actions;
 
+    KActionCollection* actionCollection();
 };
 
 #endif // QAPTACTIONS_H
