@@ -53,8 +53,9 @@ public:
     QModelIndexList collectItems(const QModelIndex &parent) const;
     UpdateItem *itemFromIndex(const QModelIndex &index) const;
 
+    void addItem(UpdateItem *item);
     bool setData(const QModelIndex &index, const QVariant &value, int role);
-    void addResources(const QList<AbstractResource*>& res);
+    void updateCheckStates();
 
     enum Columns {
         NameColumn = 0,
@@ -63,18 +64,13 @@ public:
     };
 
 private:
-    void addResource(AbstractResource* res);
-    void addItem(UpdateItem *item);
     UpdateItem *m_rootItem;
-    UpdateItem* m_systemItem;
-    UpdateItem* m_appItem;
-    UpdateItem* m_securityItem;
 
 public Q_SLOTS:
     void packageChanged();
 
 Q_SIGNALS:
-    void checkApps(const QList<AbstractResource*>& apps, bool checked);
+    void checkApps(QList<AbstractResource*> apps, bool checked);
 };
 
 #endif // UPDATEMODEL_H
